@@ -1,4 +1,4 @@
-#-----------------------------------------------------------------
+# -----------------------------------------------------------------
 # pycparser: serialize_ast.py
 #
 # Simple example of serializing AST
@@ -6,11 +6,12 @@
 # Hart Chu [https://github.com/CtheSky]
 # Eli Bendersky [https://eli.thegreenplace.net/]
 # License: BSD
-#-----------------------------------------------------------------
+# -----------------------------------------------------------------
 import pickle
 import sys
+import tempfile
 
-sys.path.extend(['.', '..'])
+sys.path.extend([".", ".."])
 from pycparser import c_parser
 
 text = r"""
@@ -20,15 +21,15 @@ void func(void)
 }
 """
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     parser = c_parser.CParser()
     ast = parser.parse(text)
-    dump_filename = 'ast.pickle'
-
-    with open(dump_filename, 'wb') as f:
+    with tempfile.NamedTemporaryFile(delete=False, suffix=".pickle") as f:
+        dump_filename = f.name
         pickle.dump(ast, f, protocol=pickle.HIGHEST_PROTOCOL)
+        print(f"Dumped to {dump_filename}")
 
     # Deserialize.
-    with open(dump_filename, 'rb') as f:
+    with open(dump_filename, "rb") as f:
         ast = pickle.load(f)
         ast.show()
